@@ -4,12 +4,12 @@
 #' based on methodology developed in Sample Size Calculations for Micro-randomized Trials in
 #' mHealth by Liao et al. (2016) <DOI:10.1002/sim.6847>.
 #'
-#' @param days Duration of the study.
-#' @param occ_per_day Number of decision time points per day.
-#' @param prob Randomization probability, i.e. the probability of assigning the treatment at a decision time
+#' @param days The duration of the study.
+#' @param occ_per_day The number of decision time points per day.
+#' @param prob The randomization probability, i.e. the probability of assigning the treatment at a decision time
 #'             point. This can be constant, or time-varying probabilities can be specified by by a vector
 #'             specifying randomization probabilities for each day or decision time.
-#' @param beta_shape The trend for the proximal treatment effect, choices are constant, linear or quadratic.
+#' @param beta_shape The trend for the proximal treatment effect; choices are constant, linear or quadratic.
 #' Note:
 #'  \enumerate{
 #'              \item{Constant} The proximal treatment effect stays constant over the study.
@@ -25,10 +25,10 @@
 #'              trend.
 #'  }
 #'
-#' @param beta_mean Average of proximal treatment effect.
-#' @param beta_initial Initial value of proximal treatment effect when beta_shape is linear or quadratic.
+#' @param beta_mean The average of proximal treatment effect.
+#' @param beta_initial The initial value of proximal treatment effect when beta_shape is linear or quadratic.
 #' @param beta_quadratic_max Day of maximal proximal treatment effect when beta_shape is quadratic.
-#' @param tau_shape The pattern for expected availability, choices are constant, linear or quadratic.
+#' @param tau_shape The pattern for expected availability; choices are constant, linear or quadratic.
 #' Note:
 #'  \enumerate{
 #'              \item{Constant} The expected availability stays constant over the study.
@@ -42,13 +42,14 @@
 #'              input values of initial and average availability.
 #'  }
 #'
-#' @param tau_mean Average of expected availability.
-#' @param tau_initial Initial Value of expected availability when tau_shape is linear or quadratic.
-#' @param tau_quadratic_max Changing point of availability when tau_shape is quadratic.
-#' @param power power
-#' @param sigLev Significance level
+#' @param tau_mean The average of expected availability.
+#' @param tau_initial The initial Value of expected availability when tau_shape is linear or quadratic.
+#' @param tau_quadratic_max The changing point of availability when tau_shape is quadratic.
+#' @param dimB The number of parameters used in the main/average effect of proximal outcome.
+#' @param power The desired power to achieve.
+#' @param sigLev The significance level or type I error rate.
 #'
-#' @return Sample size.
+#' @return The minimal sample size to achieve the desired power.
 #'
 #' @export calculateSampleSize
 #' @references Seewald, N.J.; Sun, J.; Liao, P. "MRT-SS Calculator: An R Shiny Application for Sample Size
@@ -65,6 +66,7 @@
 #'                     tau_mean=0.5,
 #'                     tau_initial=0.7,
 #'                     tau_quadratic_max=42,
+#'                     dimB=3,
 #'                     power=0.8,
 #'                     sigLev=0.05)
 #'
@@ -80,97 +82,35 @@
 #'                     tau_mean=0.5,
 #'                     tau_initial=0.7,
 #'                     tau_quadratic_max=42,
+#'                     dimB=3,
 #'                     power=0.8,
 #'                     sigLev=0.05)
 
 calculateSampleSize <- function(days,occ_per_day,prob,
                                 beta_shape,beta_mean,beta_initial,beta_quadratic_max,
-                                tau_shape,tau_mean,tau_initial,tau_quadratic_max,
+                                tau_shape,tau_mean,tau_initial,tau_quadratic_max,dimB,
                                 power,sigLev){
 
-  if(power < 0){
-    stop("Error: Please specify the power greater than or equal to 0")
+  if(power <= 0){
+
+    stop("Error: Please specify the power greater than 0")
+
   }
-  if(power > 1){
-    stop("Error: Error: Please specify the power less than or equal to 1")
+  if(power >= 1){
+
+    stop("Error: Please specify the power less than 1")
+
   }
   beta_shape <- tolower(beta_shape)
   tau_shape <- tolower(tau_shape)
   validateParameters(days,occ_per_day,prob,
                      beta_shape,beta_mean,beta_initial,beta_quadratic_max,
-                     tau_shape,tau_mean,tau_initial,tau_quadratic_max,
+                     tau_shape,tau_mean,tau_initial,tau_quadratic_max,dimB,
                      sigLev)
 
   beta_input <- generateBeta(days,occ_per_day,beta_shape,beta_mean,beta_initial,beta_quadratic_max)
   tau_input <- generateTau(days,occ_per_day,tau_shape,tau_mean,tau_initial,tau_quadratic_max)
 
-  ### calculate sample size ###
-
-  # ### Generate the current result of sample size for Quadratic proximal treatment effect and
-  # ### constant, linear and quadratic expected availability
-  # if(beta_shape == "quadratic"){
-  #
-  #   total = days*occ_per_day;
-  #   input_avail = vector('numeric', total)
-  #   input_effect = vector('numeric',total)
-  #
-  #   ### proximal treatment effect is consant on each day ###
-  #   for(k in 1:days)
-  #   {
-  #     input_effect[(occ_per_day*k-occ_per_day+1):(occ*k)] = replicate(occ_per_day, beta_input[k])
-  #   }
-  #
-  #   ### expected availability is constant on each day ###
-  #   for(k in 1:days)
-  #   {
-  #     input_avail[(occ_per_day*k-occ_per_day+1):(occ_per_day*k)] = replicate(occ_per_day, tau_input[k])
-  #   }
-  #
-  #   if(length(prob) == 1){
-  #
-  #     ### If the randomization probability is constant ###
-  #
-  #     N <- SampleSize(input_effect, input_avail, delta = prob, alpha0=sigLev, beta0=power, setup = list(days = days, occ.per.day = occ_per_day), p=3, q=3, Nmax=1000)
-  #
-  #     if(N > 10){
-  #       print(paste( "The required sample size is %3d to attain %5.2f %s power when the significance level is %4.2f", N, power*100, "%", sigLev))
-  #     }else{
-  #       ### if the calculated sample size is less than 10, we won't output the exact sample size ###
-  #       print(paste("The required sample size is less than or equal to 10 to attain %5.2f %s power when the significance level is  %4.2f.",power*100,"%",sigLev))
-  #     }
-  #   }else{
-  #
-  #     ### If the randomization probability is time-varying ###
-  #
-  #     if(length(prob) == days){
-  #
-  #       ### if the input probabibility is respect to days ###
-  #
-  #       N <- SampleSize(input_effect, input_avail, prob, alpha0=sigLev, beta0=power, setup=list(days = days, occ.per.day = occ_per_day), p=3, q=3, Nmax=1000)
-  #
-  #       if(N > 10){
-  #         print(paste("The required sample size is %3d to attain %5.2f %s power when the significance level is %4.2f.", N, power*100, "%", sigLev))
-  #       }
-  #       else
-  #       {      ### if the calculated sample size is less than 10, we won't output the exact sample size ###
-  #         print(paste("The required sample size is less than or equal to 10 to attain %5.2f %s power when the significance level is %4.2f.", power*100,"%",sigLev))
-  #       }
-  #      }else if(length(delta) == days * occ_per_day){
-  #
-  #       ### if the input probability is respect to decision times ###
-  #
-  #         N <- SampleSize(input_effect, input_avail, delta=prob, alpha0=sigLev, beta0=power, setup=list(days = days, occ.per.day = occ_per_day), p=3, q=3, Nmax=1000)
-  #
-  #         if(N > 10){
-  #           print(paste("The required sample size is %3d to attain %5.2f %s power when the significance level is %4.2f.", N, power*100,"%", sigLev))
-  #         }else{
-  #           print(paste("The required sample size is less than or equal to 10 to attain %5.2f %s power when the significance level is %4.2f.", power*100,"%",sigLev))
-  #         }
-  #     }else{
-  #       print(paste("Parameter Prob has wrong length!"))
-  #     }
-  #   }
-  # }
 
   total <- days*occ_per_day
   input_avail <- vector('numeric', total)
@@ -182,31 +122,40 @@ calculateSampleSize <- function(days,occ_per_day,prob,
   } else if(beta_shape == "linear"){
     p_input <- 2
   }
-  ### We assume that the proximal treatment effect is consant on each day ###
-  for(k in 1:days)
-  {
+
+  for(k in 1:days){
+
     input_effect[(occ_per_day*k-occ_per_day+1):(occ_per_day*k)] = replicate(occ_per_day, beta_input[k])
+
   }
 
-  ### We assume that the expected availability is constant on each day ###
-  for(k in 1:days)
-  {
+
+  for(k in 1:days){
+
     input_avail[(occ_per_day*k-occ_per_day+1):(occ_per_day*k)] = replicate(occ_per_day, tau_input[k])
+
   }
 
   if(length(prob) == 1 || length(prob) == days || length(prob) == days*occ_per_day){
 
-      N <- SampleSize(days, occ_per_day, input_effect, input_avail, delta = prob, alpha0=sigLev, beta0=power, p=p_input, q=3, Nmax=1000)
+      N <- SampleSize(days, occ_per_day, input_effect, input_avail, delta = prob, alpha0=sigLev, beta0=power, p=p_input, q=dimB, Nmax=1000)
 
       if(N > 10){
+
         print(sprintf("The required sample size is %3d to attain %5.2f%s power when the significance level is %4.2f.", N, power*100,"%",sigLev))
+
       }else{
+
         ### if the calculated sample size is less than 10, we won't output the exact sample size ###
+
         print(sprintf("The required sample size is less than or equal to 10 to attain  %5.2f %s power when the significance level is %4.2f.", power*100, "%", sigLev))
+
       }
 
   }else{
-    print(paste("Parameter Prob has wrong length!"))
+
+    print(paste("The input randomization probabilities (Prob) has wrong length!"))
+
   }
   return(N)
 
